| Home | Libraries | People | FAQ | More

## Navigation

Boost.Math documentation is provided in both HTML and PDF formats.

- Tutorials are listed in the Table of Contents and include many examples that should help you get started quickly.
- Source code of the many Examples will often be your quickest starting point.
- Index (general) includes all entries.
- Specific Indexes list only functions, class signatures, macros and typedefs.

###### Using the Indexes

The main index will usually help, especially if you know a word describing what it does, without needing to know the exact name chosen for the function.

| Tip
When using the index, keep in mind that clicking on an index term only takes you to the section containing the index entry. This section may be several pages long, so you may need to use the find facility of your browser or PDF reader to get to the index term itself.

| Tip
A PDF reader usually allows a global find; this can be really useful if the term you expect to be indexed is not the one chosen by the authors. You might find searching the PDF version and viewing the HTML version will locate an elusive item.